@@ -10,6 +10,5 @@ use Carp   qw'croak';
 extends 'PDK::Device::Cisco';
 use namespace::autoclean;
 
-# 标记类为不可变，以提高性能
 __PACKAGE__->meta->make_immutable;
-1;    # 返回真值以表示模块加载成功
+1;
